# README #

Kaipy is a python package designed to assist with analysis and visualization of data produced by the [Multiscale Atmosphhere Geospace Environment Model](https://cgs.jhuapl.edu/Models/mage.php) developed by the [Center for Geospace Storms](https://cgs.jhuapl.edu/)

### What is this repository for? ###

* Package Quick summary
* Version 0.1

### How do I get set up? ###

* Install python verison 3.8
* pip install kaipy


### Contribution guidelines ###

* All contributions should be made by making a branch of the development branch and submiting a pull request.


### Who do I talk to? ###

* For more information about the kaipy project contact Michael Wiltberger via email to [wiltbemj@ucar.edu](mailto:wiltbemj@ucar.edu?subject=Kaipy)
